==> aliyun-python-sdk-dybaseapi-1.0.1.tar.gz: aliyun-python-sdk-dybaseapi-1.0.1/aliyunsdkdybaseapi/request/v20170525/QueryTokenForMnsQueueRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class QueryTokenForMnsQueueRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Dybaseapi', '2017-05-25', 'QueryTokenForMnsQueue','Dybaseapi')

	def get_QueueName(self):
		return self.get_query_params().get('QueueName')

	def set_QueueName(self,QueueName):
		self.add_query_param('QueueName',QueueName)

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_MessageType(self):
		return self.get_query_params().get('MessageType')

	def set_MessageType(self,MessageType):
		self.add_query_param('MessageType',MessageType)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

==> aliyun-python-sdk-dybaseapi-1.0.2.tar.gz: aliyun-python-sdk-dybaseapi-1.0.2/aliyunsdkdybaseapi/request/v20170525/QueryTokenForMnsQueueRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class QueryTokenForMnsQueueRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Dybaseapi', '2017-05-25', 'QueryTokenForMnsQueue','dybaseapi')

	def get_QueueName(self):
		return self.get_query_params().get('QueueName')

	def set_QueueName(self,QueueName):
		self.add_query_param('QueueName',QueueName)

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_MessageType(self):
		return self.get_query_params().get('MessageType')

	def set_MessageType(self,MessageType):
		self.add_query_param('MessageType',MessageType)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)
